      SUBROUTINE MMULT(A,B,C,N,NX)
C
C     THIS SUBROUTINE DOES MATRIX MULTIPLICATION: A*B=C
C
      IMPLICIT REAL*8 (A-H,O-Z)
      COMPLEX*16 A(NX,NX),B(NX,NX),C(NX,NX)
C
      DO 500 I=1,N
      DO 400 J=1,N
C
      C(I,J)=DCMPLX(0.0,0.0)
      DO 300 II=1,N
      C(I,J)=C(I,J)+A(I,II)*B(II,J)
  300 CONTINUE
C
  400 CONTINUE
  500 CONTINUE
C
      RETURN
      END 
