      SUBROUTINE PRTTL(TITLE,FREQ,ZS,ZR,TL)
C
C     THIS SUBROUTINE PRINTS THE TRANSMISSION LOSS WHICH WAS WRITTEN
C     ON TAPE10 IN CPRES.
C
      IMPLICIT REAL*8 (A-H,O-Z)
      DIMENSION ZR(1),TL(1)
C
      CHARACTER*6 IDENT
      CHARACTER*10 TITLE(8),DA
C
      READ(10,10) (TITLE(I),I=1,8)
   10 FORMAT(8A10)
      READ(10,20) DA,FREQ,ZS,NR,ND
   20 FORMAT(A10,2F13.7,2I5)
      READ(10,30) (ZR(I),I=1,ND)
   30 FORMAT(20F13.7)
C
C
      WRITE(9,100)
  100 FORMAT(///)
      WRITE(9,300) (TITLE(I),I=1,8),DA
  300 FORMAT(1X,8A10,5X,A10)
      WRITE(9,500) ZS
  500 FORMAT(21H TRANSMISSION LOSS --,//
     1           15H INPUT DEPTH = ,F7.1,2H M)
      WRITE(9,520) FREQ,(ZR(I),I=1,ND)
  520 FORMAT(14H FREQUENCY   =,F7.1,3H HZ//
     1       9H DEPTH=  ,20F6.1)
      WRITE(9,600)
  600 FORMAT(8H RANGE  ,120(1H-))
C
  800 CONTINUE
C
      READ(10,810,END=900) RKM,(TL(I),I=1,ND)
  810 FORMAT(F13.7,20F13.7)
C
      WRITE(9,850) RKM,(TL(I),I=1,ND)
  850 FORMAT(1X,F8.2,20F6.1)
C
      GO TO 800
C
  900 CONTINUE
C
      REWIND 10
C
      RETURN
      END
