REM
REM COMPILE ALL SUBROUTINES FOR COUPLE
REM
REM lf90 -c COUPLE
REM
lf90 -c ABORTC.FOR 
lf90 -c AMAT.FOR
lf90 -c AVGIN.FOR 
lf90 -c BACKSUB.FOR 
lf90 -c BATHY.FOR 
lf90 -c BESSJ0.FOR 
lf90 -c BESSY0.FOR 
lf90 -c BDF.FOR 
lf90 -c BMAT.FOR
lf90 -c BOTDEPS.FOR 
lf90 -c CCDS.FOR 
lf90 -c CDFUN.FOR
lf90 -c CDJ0.FOR 
lf90 -c CDSRT.FOR 
lf90 -c CDTAN.FOR 
lf90 -c CEGV.FOR
lf90 -c CEXIB.FOR
lf90 -c CEXIBD.FOR
lf90 -c CEXIW.FOR
lf90 -c CEXIWB.FOR
lf90 -c CEXIWD.FOR
lf90 -c CFACIN.FOR 
lf90 -c CHDH.FOR 
lf90 -c CHECK.FOR 
lf90 -c CHOLDC.FOR
lf90 -c CIB0.FOR 
lf90 -c CSYMEIG.FOR 
lf90 -c CISP.FOR 
lf90 -c CIW0.FOR 
lf90 -c CIWB.FOR 
lf90 -c CJDJ.FOR 
lf90 -c CLINEQS.FOR 
lf90 -c CMMULT.FOR 
lf90 -c CPRES.FOR 
lf90 -c CPTBH.FOR 
lf90 -c CPTURB.FOR 
lf90 -c CRSCUP.FOR
lf90 -c CRSCUPB.FOR
lf90 -c CSDS.FOR 
lf90 -c CUPB.FOR 
lf90 -c CUPBW.FOR 
lf90 -c CUPW.FOR 
lf90 -c CUPWB.FOR 
lf90 -c CVMULT.FOR 
lf90 -c DREAL.FOR 
lf90 -c EGNVAL.FOR 
lf90 -c ESPI.FOR 
lf90 -c FILE.FOR 
lf90 -c FORESUB.FOR
lf90 -c GALRKN.FOR 
lf90 -c GAMA.FOR 
lf90 -c GAMA0.FOR 
lf90 -c GAMA00.FOR 
lf90 -c GENAB.FOR 
lf90 -c HEADER.FOR 
lf90 -c HK01.FOR 
lf90 -c HK02.FOR 
lf90 -c INDEP.FOR 
lf90 -c INPUT.FOR 
lf90 -c MGS.FOR 
lf90 -c MMULT.FOR 
lf90 -c PROPM.FOR 
lf90 -c PRTMAT.FOR 
lf90 -c PRTTL.FOR
lf90 -c PTURB.FOR 
lf90 -c RCF.FOR 
lf90 -c SEARCH.FOR 
lf90 -c TMMULT.FOR 
lf90 -c ZCEXIB.FOR
lf90 -c ZCEXIW.FOR
