      REAL*8 FUNCTION DREAL(Z)
C
C     THIS FUNCTION PROVIDES THE DOUBLE PRECISION REAL PART
C     OF A COMPLEX*16 NUMBER 
C
      IMPLICIT REAL*8 (A-H,O-Z)
      COMPLEX*16 Z,CI
C
      CI=DCMPLX(0.0D0,1.0D0)
      DREAL=DIMAG(CI*Z)
C 
      RETURN
      END
