      COMPLEX*16 FUNCTION CISP(AA,XA,BB,XB)
C
C     THIS FUNCTION IS USED TO EVALUATE THE INDEFINITE INTEGRAL OF
C     CDSIN(AA*XA)*CDSIN(BB*XB) WHERE XA AND XB EQUALS X OR X-HB.
C
      IMPLICIT REAL*8 (A-H,O-Z)
      COMPLEX*16 AA,BB,U,V
C
      COMMON /BLKEVN/ HB,CW,CB,FKW,FKB,ROHW,ROHB,ATEN
C
      IF(CDABS(AA-BB)/FKB .LT. .5D-13) GO TO 200
C
      U=BB*CDSIN(AA*XA)*CDCOS(BB*XB)-AA*CDCOS(AA*XA)*CDSIN(BB*XB)
      V=AA**2-BB**2
      CISP=U/V
      GO TO 300
C
  200 CONTINUE
      U=CDCOS(AA*(XA-XB))*XA/2.0
      V=CDSIN(AA*(XA+XB))/(4.0*AA)
      CISP=U-V
C
  300 CONTINUE
C
      RETURN
      END
