      COMPLEX*16 FUNCTION CIWB(H1,H2,ALPHA1,ALPHA2,BETA1,BETA2)
C
C     THIS FUNCTION EVALUATES THE PART OF THE CROSS COUPLING INTEGRAL
C     BETWEEN WATER AND SEDIMENT. 
C
      IMPLICIT REAL*8 (A-H,O-Z)
      COMPLEX*16 ALPHA1,ALPHA2,BETA1,BETA2,Z,U,V,W
      COMPLEX*16 CSDS,CCDS
      COMMON /BLKEVN/ HB,CW,CB,FKW,FKB,ROHW,ROHB,ATEN
C
C      FOLLOWING LINE IS A BUG AND SHOULD BE REPLACED AS BELOW
CC      IF(H2 .LE. H1) GO TO 200
C
      IF(H2 .GE. H1) GO TO 200
      IF(CDABS(ALPHA1-BETA2) .LT. .5D-13) GO TO 100
C
      U=FKB**4*CDSIN(ALPHA2*H2)/(ALPHA1*ALPHA2)
      Z=ALPHA1**2-BETA2**2
      V=BETA2*CDSIN(ALPHA1*H1)*CCDS(H1,H2,BETA2)-
     1  ALPHA1*CDCOS(ALPHA1*H1)*CSDS(H1,H2,BETA2)
      W=BETA2*CDSIN(ALPHA1*H2)*CCDS(H2,H2,BETA2)-
     1  ALPHA1*CDCOS(ALPHA1*H2)
      CIWB=U*(V-W)/Z
      GO TO 300
C
  100 CONTINUE
C
      U=FKB**4*CDSIN(ALPHA2*H2)
      Z=ALPHA1*ALPHA2*CDSIN(ALPHA1*(H2-HB))
      V=CDCOS(ALPHA1*HB)*(H1-H2)/2.
      W=CDSIN(ALPHA1*(2.*H2-HB))-CDSIN(ALPHA1*(2.*H1-HB))      
      W=W/(4.*ALPHA1)
      CIWB=U*(V-W)/Z
      GO TO 300 
C
  200 CONTINUE
C
      CIWB=DCMPLX(0.0,0.0)           
C
  300 CONTINUE
C    
      RETURN
      END
