DEL COUPLE.EXE
lf90 -c COUPLE.FOR                                                     
REM lf90 -c GALRKN.FOR                                                     
REM lf90 -c AMAT.FOR                                                     
REM lf90 -c AVGIN.FOR                                                     
REM lf90 -c BMAT.FOR                                                     
REM lf90 -c CRSCUPB.FOR                                                     
REM lf90 -c CUPB.FOR                                                     
REM lf90 -c CUPBW.FOR                                                     
REM lf90 -c CUPW.FOR                                                     
REM lf90 -c CUPWB.FOR                                                     
REM lf90 -c CEXIW.FOR                                                     
REM lf90 -c CEXIWB.FOR                                                     
REM lf90 -c CEXIWD.FOR                                                     
REM lf90 -c ZCEXIW.FOR                                                     
REM lf90 -c INPUT.FOR                                                     
REM lf90 -c INDEP.FOR                                                     
REM lf90 -c SEARCH.FOR                                                     
lf90 -pack @COUPLE.LNK
