#
#Batch file to run couple
#use"%s/oldname/newname/g" to change input data name
#
cd /home/oalib/evans/couple97
cp examp3.dat COUPLE.DAT
couple
cp COUPLE.LOG examp3.log
cp COUPLE.PRT examp3.prt
rm COUPLE.LOG
rm COUPLE.PRT
cp COUPLE.TL examp3.tl
cp COUPLES.TL examp3s.tl
cp COUPLEO.TL examp3o.tl
cp COUPLEI.TL examp3i.tl
cp COUPLE.CPR examp3.cpr
cp COUPLES.CPR examp3s.cpr
cp COUPLEO.CPR examp3o.cpr
cp COUPLEI.CPR examp3i.cpr
rm COUPLE.TL
rm COUPLES.TL
rm COUPLEO.TL
rm COUPLEI.TL
rm COUPLE.CPR
rm COUPLES.CPR
rm COUPLEO.CPR
rm COUPLEI.CPR
rm COUPLE.DAT
#
#rm SCRACH21.DAT
#rm SCRACH2.DAT
#rm SCRACH3.DAT
#rm SCRACH4.DAT
#rm SCRACH8.DAT
#rm SCRACH18.DAT
