      COMPLEX*16 FUNCTION CIW0(H1,H2,ALPHA1,ALPHA2)
C
C     THIS FUNCTION EVALUATES THE PART OF THE CROSS COUPLING INTEGRAL
C     IN THE WATER. THIS VERSION OMITS DIVISION BY ROHW.
C
      IMPLICIT REAL*8 (A-H,O-Z)
      COMPLEX*16 ALPHA1,ALPHA2,CISP,U,V
      COMMON /BLKEVN/ HB,CW,CB,FKW,FKB,ROHW,ROHB,ATEN
C
      HMIN=DMIN1(H1,H2)
      U=FKB**4/(ALPHA1*ALPHA2)
      V=CISP(ALPHA1,HMIN,ALPHA2,HMIN)
      CIW0=U*V
C
      RETURN
      END
