      SUBROUTINE CHECK(M,EGVR,IABRT,MX)
C
C     THIS SUBROUTINE CHECKS FOR MULTIPLE EIGEN VALUES
C     AND RETURNS THE NUMBER OF THESE IN IABRT
C
      IMPLICIT REAL*8 (A-H,O-Z)
      COMPLEX*16 EGVR(MX)
C
      MM1=M-1
      IABRT=0
C
      DO 200 I=1,MM1
      IP1=I+1
      DO 100 II=IP1,M
C
      IF(CDABS(EGVR(I)-EGVR(II)) .LT. .1D-12) IABRT=IABRT+1
C
  100 CONTINUE
  200 CONTINUE
C
      RETURN
      END
