      COMPLEX*16 FUNCTION CHDH(EGV,RNG1,RNG2)
C
C     THIS FUNCTION COMPUTES AN ASYMPTOTIC APPROX. FOR THE RATIO OF
C     HANKEL FUNCTIONS OF ORDER ZERO TYPE ONE WHICH APPEARS IN
C     THE REPRESENTATION OF THE COMPLEX PRESSURE. RNG2 IS THE CURRENT
C     RANGE AND RNG1 IS THE RANGE OF THE LAST (.LE. RNG2) INTERFACE.
C     THIS FUNCTION ALSO APPEARS IN TRANSM.
C
      IMPLICIT REAL*8 (A-H,O-Z)
      COMMON /BLKEVN/ HB,CW,CB,FKW,FKB,ROHW,ROHB,ATEN
      COMMON /FLAGS/ IGEOM,NEWSBC
      COMPLEX*16 ONE,CI,EGV
      COMPLEX*16 FKH
      COMPLEX*16 CDSRT 
C
      ONE=DCMPLX(1.0,0.0)
      CI=DCMPLX(0.0,1.0)
C
      FKH=FKB*CDSRT(ONE-EGV)
      IF(IGEOM .EQ. 1) THEN
      CHDH=CDEXP(CI*FKH*(RNG2-RNG1))
      ELSE
      CHDH=SQRT(RNG1/RNG2)*CDEXP(CI*FKH*(RNG2-RNG1))
      END IF
C
      RETURN
      END
