      COMPLEX*16 FUNCTION CIB0(H1,H2,ALPHA1,ALPHA2,BETA1,BETA2)
C
C     THIS FUNCTION EVALUATES THE PART OF THE CROSS COUPLING INTEGRAL
C     IN THE SEDIMENT. DIVISION BY ROHB NOT DONE IN THIS VESION.
C
      IMPLICIT REAL*8 (A-H,O-Z)
      COMPLEX*16 ALPHA1,ALPHA2,BETA1,BETA2,U,V,W,Z,B
      COMPLEX*16 CCDS,CSDS
      COMMON /BLKEVN/ HB,CW,CB,FKW,FKB,ROHW,ROHB,ATEN
C
      HMAX=DMAX1(H1,H2)
      U=FKB**4*CDSIN(ALPHA1*H1)*CDSIN(ALPHA2*H2)
      IF(CDABS(BETA1-BETA2) .LT. .5D-13) GO TO 100
      V=(BETA1**2-BETA2**2)*ALPHA1*ALPHA2
      W=BETA1*CCDS(HMAX,H1,BETA1)*CSDS(HMAX,H2,BETA2)
     1  -BETA2*CSDS(HMAX,H1,BETA1)*CCDS(HMAX,H2,BETA2)
      GO TO 500
C
  100 CONTINUE
      V=2.*BETA1*ALPHA1*ALPHA2
      B=BETA1*(2.*HB-H1-H2)
      IF(DIMAG(B) .GT. 88.0D0) GO TO 200
      Z=CDSIN(BETA1*(H1-HB))*CDSIN(BETA1*(H2-HB)) 
      W=CCDS(HMAX,H1,BETA1)*CSDS(HMAX,H2,BETA1)-BETA1*(HMAX-HB)/Z
      GO TO 500
C
  200 CONTINUE
      W=CCDS(HMAX,H1,BETA1)*CSDS(HMAX,H2,BETA1)
C           
  500 CONTINUE
      CIB0=U*W/V
C
      RETURN
      END
