      SUBROUTINE ABORTC(IFLAG)       
C    
C     THIS SUBROUTINE ABORTS THE RUN FOR THE FOLLOWING REASONS:
C
C      0. FAILURE TO CONVERGE IN CEGV
C      1. MULTIPLE EIGEN VALUES IN SEARCH   
C      2. ZERO DETERMINANT RETURNED BY DECOMP IN CLINEQS
C      3. FAILURE TO IMPROVE BY IMPRUV IN CLINEQS ON 
C         RETURN TO COUPLE
C      4. FAILURE TO CONVERGE IN CIGMAT
C    
      IMPLICIT REAL*8 (A-H,O-Z)
      WRITE(9,100) IFLAG
  100 FORMAT(1X,///,' ***** RUN ABORTED FOR REASON ',I5,
     1       '  *****',////)
C
      WRITE(9,200)
  200 FORMAT(5X,40H0. FAILURE TO CONVERGE IN CEGV          /
     1       5X,40H1. MULTIPLE EIGEN VALUES IN SEARCH      /
     2       5X,40H2. ZERO DETERMINANT RETURNED BY DECOMP  /
     3       5X,40H3. FAILURE TO INPROVE BY IMPRUV         /
     4       5X,40H3. FAILURE TO CONVERGE IN CIGMAT        /)
C              
      STOP
      END
